@@ -120,7 +120,11 @@ class Message:
                                                 if exist(self.extensions, 'mentionedArray')
                                                 else False
                                             )
-        self.icon:            str | None       = exist(_cm['author'], 'icon')
+        if 'author' in _cm:
+            self.icon:            str | None       = exist(_cm['author'], 'icon')
+        else:
+            self.icon = None
+            
         self.id:              str | None       = exist(_cm, 'messageId')
         self.media_type:      str | None       = exist(_cm, 'mediaType')
         self.mentioned_users: list[str] | None = (
@@ -232,7 +236,6 @@ class User:
         'comments_count',
         'created_time',
         'followers_count',
-        'following_count',
         'id',
         'im_following',
         'is_online',
@@ -252,7 +255,7 @@ class User:
             self.com             = exist(j, 'ndcId')
             self.comments_count  = exist(j, 'commentsCount', in_str=False)
             self.created_time    = exist(j, 'createdTime')
-            self.following_count = exist(j, 'membersCount')
+            self.followers_count = exist(j, 'membersCount')
             self.im_following    = (True if j['followingStatus'] == 1 else False) if exist(j, 'followingStatus') else None
             self.level           = exist(j, 'level', in_str=False)
             self.nickname        = exist(j, 'nickname')
