@@ -17,6 +17,9 @@ def exit(m):
     sys.exit(1)
 
 def create(name):
+    if Path('.git').exists():
+        _run('rmdir .git /s /q', shell=True)
+
     return {
         'Starting repository':                               'git init',
         'Adding files':                                      'git add .',
@@ -72,9 +75,13 @@ def init():
         f.write('amsync')
 
     if not Path('.env').exists():
+        print(f'{Fore.CYAN}Email{Fore.WHITE}: ', end='')
+        email = input()
+        print(f'{Fore.CYAN}Password{Fore.WHITE}: ', end='')
+        password = input()
         with open('.env', 'w') as f:
-            f.write('EMAIL=\nPASSWORD=')
-    
+            f.write(f'EMAIL={email}\nPASSWORD={password}')
+
     if not Path('bot.py').exists():
         with open('bot.py', 'w') as f:
             f.write(
@@ -128,6 +135,10 @@ def main():
     if args == 'workers':
         print(run(workers()))
 
+    if args == 'update':
+        run(update())
+        print('Done')
+
     if 'create' in args:
         try:
             app = args.split()[1]
@@ -140,7 +151,7 @@ def main():
 
     elif args == 'apps':
         print(run(apps()))
-            
+
 
     elif 'destroy' in args:
         try:
@@ -150,7 +161,7 @@ def main():
             app = run(apps()).split('\n')[1:-2]
             if not app or not app[0]:
                 exit('No project found')
-            while True:    
+            while True:
                 clear()
                 for i, e in enumerate(app):
                     print(f'{Fore.CYAN}{i}. {Fore.WHITE}{e}')
@@ -164,5 +175,4 @@ def main():
                 break
 
             clear()
-            print(f'Destroing {Fore.CYAN}{app[n]}{Fore.WHITE}')
-            run(destroy(app[n]))
+            print(run(destroy(app[n])))
